==> herman-1.1.1.tar.gz: herman-1.1.1/setup.py <==
import os
import sys
import warnings
from distutils.core import setup
from distutils.extension import Extension
from distutils.version import StrictVersion

f = open(os.path.join(os.path.dirname(__file__), 'README.rst'))
readme = f.read()
f.close()

setup_kwargs = {}
try:
    from Cython.Distutils import build_ext
    from Cython import __version__ as cython_version
    if StrictVersion(cython_version) < StrictVersion('0.22.1'):
        warnings.warn('Your Cython appears to be an older version. You may '
                      'need to upgrade Cython in order to build the peewee '
                      'C extensions.')
except ImportError:
    cython_installed = False
else:
    cython_installed = True

speedups_ext_module = Extension(
    'playhouse._speedups',
    ['playhouse/_speedups.pyx'])
sqlite_udf_module = Extension(
    'playhouse._sqlite_udf',
    ['playhouse/_sqlite_udf.pyx'])
sqlite_ext_module = Extension(
    'playhouse._sqlite_ext',
    ['playhouse/_sqlite_ext.pyx'])


ext_modules = []
if cython_installed:
    ext_modules.extend([
        speedups_ext_module,
        sqlite_udf_module,
        sqlite_ext_module])

if ext_modules:
    setup_kwargs.update(
        cmdclass={'build_ext': build_ext},
        ext_modules=ext_modules)

setup(
    name='herman',
    version=__import__('peewee').__version__,
    description='a little fork of peewee',
    long_description=readme,
    author='Derek Anderson',
    author_email='public@kered.org',
    url='http://github.com/keredson/peewee/',
    packages=['playhouse'],
    py_modules=['peewee', 'pwiz'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
    scripts = ['pwiz.py'],
    **setup_kwargs
)

==> herman-1.2.1.tar.gz: herman-1.2.1/setup.py <==
import os
import sys
import warnings
from distutils.core import setup
from distutils.extension import Extension
from distutils.version import StrictVersion

f = open(os.path.join(os.path.dirname(__file__), 'README.rst'))
readme = f.read()
f.close()

setup_kwargs = {}
try:
    from Cython.Distutils import build_ext
    from Cython import __version__ as cython_version
    if StrictVersion(cython_version) < StrictVersion('0.22.1'):
        warnings.warn('Your Cython appears to be an older version. You may '
                      'need to upgrade Cython in order to build the peewee '
                      'C extensions.')
except ImportError:
    cython_installed = False
else:
    cython_installed = True

speedups_ext_module = Extension(
    'playhouse._speedups',
    ['playhouse/_speedups.pyx'])
sqlite_udf_module = Extension(
    'playhouse._sqlite_udf',
    ['playhouse/_sqlite_udf.pyx'])
sqlite_ext_module = Extension(
    'playhouse._sqlite_ext',
    ['playhouse/_sqlite_ext.pyx'])


ext_modules = []
if cython_installed:
    ext_modules.extend([
        speedups_ext_module,
        sqlite_udf_module,
        sqlite_ext_module])

if ext_modules:
    setup_kwargs.update(
        cmdclass={'build_ext': build_ext},
        ext_modules=ext_modules)

setup(
    name='herman',
    version=__import__('peewee').__herman_version__,
    description='a little fork of peewee',
    long_description=readme,
    author='Derek Anderson',
    author_email='public@kered.org',
    url='http://github.com/keredson/peewee/',
    packages=['playhouse'],
    py_modules=['peewee', 'pwiz'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
    scripts = ['pwiz.py'],
    **setup_kwargs
)
